@@ -32,10 +32,13 @@ def main():
             if plugin.can_handle(arguments.which):
                 plugin.run(arguments, os.getcwd())
 
-    except AttributeError:
+    except AttributeError as e:
         parser.print_help()
         exit(1)
 
+    except Exception as e:
+        print(e)
+        exit(1)
 
 if __name__ == '__main__':
     main()
